==> Accuinsight-1.0.3.tar.gz: Accuinsight-1.0.3/Accuinsight/modeler/core/LcConst/LcConst.py <==
LOGGING_TIME = 'logging_time'
LOGGING_RUN_ID = 'logging_run_id'
FITTED_MODEL = 'fitted_model'
ALL_MODEL_PARAMS = 'all_model_params'
SELECTED_PARAMS = 'selected_params'
SELECTED_METRICS = 'selected_metrics'
VALUE_ERROR = 'ValueError'
TAG = 'tag'

# using dl framework
RUN_NAME_KERAS = 'keras'
RUN_NAME_TENSORFLOW = 'tensorflow'

# for run object
RUN_BASE_PATH = 'base_path'
RUN_ROOT_PATH = '/runs/'
RUN_PREFIX_PATH = 'prefix_path'

RUN_OBJ_NAME = 'run_name'

RUN_OBJ_JSON_PATH = 'json_path'
RUN_OBJ_CSV_PATH = 'csv_path'
RUN_OBJ_VISUAL_PATH = 'visual_path'

RUN_OBJ_MODEL_JSON_PATH = 'model_json_path'
RUN_OBJ_VISUAL_CSV_PATH = 'visual_csv_path'
RUN_OBJ_VISUAL_JSON_PATH = 'visual_json_path'
RUN_OBJ_BEST_MODEL_H5_PATH = 'save_best_model_h5_path'
RUN_OBJ_BEST_MODEL_JSON_PATH = 'save_best_model_json_path'
RUN_OBJ_BEST_MODEL_JOBLIB_PATH = 'save_best_model_joblib_path'
RUN_OBJ_DATA_VERSION = 'data_version'
RUN_OBJ_MODEL_FILE_PATH = 'path'

##########deprecated###########
RUN_MODEL_JSON_PATH = 'model_json_full'
RUN_MODEL_VISUAL_JSON_PATH = 'visual_json_full'
RUN_MODEL_VISUAL_CSV_PATH = 'visual_csv_full'
RUN_MODEL_HDF5_PATH = 'save_model_hdf5'
RUN_MODEL_HOME_PATH = 'home_path'
RUN_RESULT_PATH = 'result_path'
#####################

TRUE_Y = 'True_y'

SOURCE_FILE_PATH = 'run_path'
SOURCE_FILE_NAME = 'filename'
SOURCE_FILE_DIGEST = 'digest'
SOURCE_FILE_GIT_REPO = 'repo'
SOURCE_FILE_GIT_COMMIT_ID = 'commit'
SOURCE_FILE_IS_DIRTY = 'is_dirty'

SOURCE_FILE_GIT_META = 'git_meta'
PYTHON_DEPENDENCY = 'dependency'

START_TIME = 'start_time'
END_TIME = 'end_time'
DELTA_TIME = 'delta_time'


ENV_PROJECT_ID='LC_PROJECT_ID'
ENV_WORKSPACE_ID='LC_WORKSPACE_ID'
ENV_EXPERIMENT_ID='LC_EXPERIMENT_ID'
ENV_USER_SSO_ID = 'LC_USER_SSO_ID'
ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'

ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
ENV_JUPYTER__HOME_DIR = '/home/work'

BACK_END_API_URL = 'api.accu'
BACK_END_API_PORT = '8080'
BACK_END_API_URI = ''

==> Accuinsight-1.0.14.tar.gz: Accuinsight-1.0.14/Accuinsight/modeler/core/LcConst/LcConst.py <==
LOGGING_TIME = 'logging_time'
LOGGING_RUN_ID = 'logging_run_id'
FITTED_MODEL = 'fitted_model'
ALL_MODEL_PARAMS = 'all_model_params'
SELECTED_PARAMS = 'selected_params'
SELECTED_METRICS = 'selected_metrics'
VALUE_ERROR = 'ValueError'
TAG = 'tag'

# using dl framework
RUN_NAME_KERAS = 'keras'
RUN_NAME_TENSORFLOW = 'tensorflow'

# for run object
RUN_BASE_PATH = 'base_path'
RUN_ROOT_PATH = '/runs/'
RUN_PREFIX_PATH = 'prefix_path'

RUN_OBJ_NAME = 'run_name'

RUN_OBJ_JSON_PATH = 'json_path'
RUN_OBJ_CSV_PATH = 'csv_path'
RUN_OBJ_VISUAL_PATH = 'visual_path'
RUN_OBJ_SHAP_PATH = 'shap_path'

# path for setting
RUN_OBJ_MODEL_FILE_PATH = 'path'
RUN_OBJ_MODEL_JSON_PATH = 'model_json_path'
RUN_OBJ_VISUAL_CSV_PATH = 'visual_csv_path'
RUN_OBJ_VISUAL_JSON_PATH = 'visual_json_path'
RUN_OBJ_SHAP_JSON_PATH = 'shap_json_path'
RUN_OBJ_BEST_MODEL_H5_PATH = 'save_best_model_h5_path'
RUN_OBJ_BEST_MODEL_JSON_PATH = 'save_best_model_json_path'
RUN_OBJ_BEST_MODEL_JOBLIB_PATH = 'save_best_model_joblib_path'
RUN_OBJ_DATA_VERSION = 'data_version'

# full path
RUN_MODEL_JSON_PATH = 'model_json_full'
RUN_MODEL_VISUAL_JSON_PATH = 'visual_json_full'
RUN_MODEL_SHAP_JSON_PATH = 'shap_json_full'
RUN_MODEL_VISUAL_CSV_PATH = 'visual_csv_full'
RUN_MODEL_HDF5_PATH = 'save_model_hdf5'
RUN_MODEL_HOME_PATH = 'home_path'
RUN_RESULT_PATH = 'result_path'

TRUE_Y = 'True_y'

SOURCE_FILE_PATH = 'run_path'
SOURCE_FILE_NAME = 'filename'
SOURCE_FILE_DIGEST = 'digest'
SOURCE_FILE_GIT_REPO = 'repo'
SOURCE_FILE_GIT_COMMIT_ID = 'commit'
SOURCE_FILE_IS_DIRTY = 'is_dirty'

SOURCE_FILE_GIT_META = 'git_meta'
PYTHON_DEPENDENCY = 'dependency'

START_TIME = 'start_time'
END_TIME = 'end_time'
DELTA_TIME = 'delta_time'

ENV_PROJECT_ID='LC_PROJECT_ID'
ENV_WORKSPACE_ID='LC_WORKSPACE_ID'
ENV_EXPERIMENT_ID='LC_EXPERIMENT_ID'
ENV_USER_SSO_ID = 'LC_USER_SSO_ID'
ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'

ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
ENV_JUPYTER_HOME_DIR = '/home/work'

DB_CONNECT_USER = 'modeler'
DB_CONNECT_PASSWD = '!Modeleradmin1234'
DB_CONNECT_HOST = 'accuinsight.mariadb.database.azure.com'
DB_CONNECT_PORT = 3306
DB_CONNECT_DB = 'modeler'
DB_CONNECT_CHARSET = 'utf8'

BACK_END_API_URI = ''
BACK_END_API_URL = 'api.accu'
BACK_END_API_PORT = '8080'
